@@ -49,7 +49,7 @@ impl From<CLK_GATING_A> for bool {
     }
 }
 #[doc = "Field `CLK_GATING` reader - Gating Clock"]
-pub struct CLK_GATING_R(crate::FieldReader<bool, CLK_GATING_A>);
+pub struct CLK_GATING_R(crate::FieldReader<bool>);
 impl CLK_GATING_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl CLK_GATING_R {
     }
 }
 impl core::ops::Deref for CLK_GATING_R {
-    type Target = crate::FieldReader<bool, CLK_GATING_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,7 +114,7 @@ impl<'a> CLK_GATING_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -136,7 +136,7 @@ impl From<CLK_SRC_SEL_A> for u8 {
     }
 }
 #[doc = "Field `CLK_SRC_SEL` reader - Clock Source Select"]
-pub struct CLK_SRC_SEL_R(crate::FieldReader<u8, CLK_SRC_SEL_A>);
+pub struct CLK_SRC_SEL_R(crate::FieldReader<u8>);
 impl CLK_SRC_SEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -169,7 +169,7 @@ impl CLK_SRC_SEL_R {
     }
 }
 impl core::ops::Deref for CLK_SRC_SEL_R {
-    type Target = crate::FieldReader<u8, CLK_SRC_SEL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -203,7 +203,7 @@ impl<'a> CLK_SRC_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 24)) | ((value as u32 & 0x07) << 24);
+        self.w.bits = (self.w.bits & !(7 << 24)) | ((value as u32 & 7) << 24);
         self.w
     }
 }
@@ -227,7 +227,7 @@ impl From<FACTOR_N_A> for u8 {
     }
 }
 #[doc = "Field `FACTOR_N` reader - Factor N"]
-pub struct FACTOR_N_R(crate::FieldReader<u8, FACTOR_N_A>);
+pub struct FACTOR_N_R(crate::FieldReader<u8>);
 impl FACTOR_N_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -266,7 +266,7 @@ impl FACTOR_N_R {
     }
 }
 impl core::ops::Deref for FACTOR_N_R {
-    type Target = crate::FieldReader<u8, FACTOR_N_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -305,12 +305,12 @@ impl<'a> FACTOR_N_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
 #[doc = "Field `FACTOR_M` reader - Factor M"]
-pub struct FACTOR_M_R(crate::FieldReader<u8, u8>);
+pub struct FACTOR_M_R(crate::FieldReader<u8>);
 impl FACTOR_M_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -318,7 +318,7 @@ impl FACTOR_M_R {
     }
 }
 impl core::ops::Deref for FACTOR_M_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -340,17 +340,17 @@ impl R {
     #[doc = "Bit 31 - Gating Clock"]
     #[inline(always)]
     pub fn clk_gating(&self) -> CLK_GATING_R {
-        CLK_GATING_R::new(((self.bits >> 31) & 0x01) != 0)
+        CLK_GATING_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bits 24:26 - Clock Source Select"]
     #[inline(always)]
     pub fn clk_src_sel(&self) -> CLK_SRC_SEL_R {
-        CLK_SRC_SEL_R::new(((self.bits >> 24) & 0x07) as u8)
+        CLK_SRC_SEL_R::new(((self.bits >> 24) & 7) as u8)
     }
     #[doc = "Bits 8:9 - Factor N"]
     #[inline(always)]
     pub fn factor_n(&self) -> FACTOR_N_R {
-        FACTOR_N_R::new(((self.bits >> 8) & 0x03) as u8)
+        FACTOR_N_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 0:4 - Factor M"]
     #[inline(always)]
