@@ -49,7 +49,7 @@ impl From<MBUS_RST_A> for bool {
     }
 }
 #[doc = "Field `MBUS_RST` reader - MBUS Reset"]
-pub struct MBUS_RST_R(crate::FieldReader<bool, MBUS_RST_A>);
+pub struct MBUS_RST_R(crate::FieldReader<bool>);
 impl MBUS_RST_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl MBUS_RST_R {
     }
 }
 impl core::ops::Deref for MBUS_RST_R {
-    type Target = crate::FieldReader<bool, MBUS_RST_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,7 +114,7 @@ impl<'a> MBUS_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -122,7 +122,7 @@ impl R {
     #[doc = "Bit 30 - MBUS Reset"]
     #[inline(always)]
     pub fn mbus_rst(&self) -> MBUS_RST_R {
-        MBUS_RST_R::new(((self.bits >> 30) & 0x01) != 0)
+        MBUS_RST_R::new(((self.bits >> 30) & 1) != 0)
     }
 }
 impl W {
