@@ -35,7 +35,7 @@ impl From<crate::W<PLL_VIDEO0_PAT1_CTRL_SPEC>> for W {
     }
 }
 #[doc = "Field `DITHER_EN` reader - Dither Enable"]
-pub struct DITHER_EN_R(crate::FieldReader<bool, bool>);
+pub struct DITHER_EN_R(crate::FieldReader<bool>);
 impl DITHER_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl DITHER_EN_R {
     }
 }
 impl core::ops::Deref for DITHER_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> DITHER_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `FRAC_EN` reader - Fraction Enable"]
-pub struct FRAC_EN_R(crate::FieldReader<bool, bool>);
+pub struct FRAC_EN_R(crate::FieldReader<bool>);
 impl FRAC_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl FRAC_EN_R {
     }
 }
 impl core::ops::Deref for FRAC_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> FRAC_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `FRAC_IN` reader - Fraction In"]
-pub struct FRAC_IN_R(crate::FieldReader<u32, u32>);
+pub struct FRAC_IN_R(crate::FieldReader<u32>);
 impl FRAC_IN_R {
     #[inline(always)]
     pub(crate) fn new(bits: u32) -> Self {
@@ -117,7 +117,7 @@ impl FRAC_IN_R {
     }
 }
 impl core::ops::Deref for FRAC_IN_R {
-    type Target = crate::FieldReader<u32, u32>;
+    type Target = crate::FieldReader<u32>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -139,12 +139,12 @@ impl R {
     #[doc = "Bit 24 - Dither Enable"]
     #[inline(always)]
     pub fn dither_en(&self) -> DITHER_EN_R {
-        DITHER_EN_R::new(((self.bits >> 24) & 0x01) != 0)
+        DITHER_EN_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 20 - Fraction Enable"]
     #[inline(always)]
     pub fn frac_en(&self) -> FRAC_EN_R {
-        FRAC_EN_R::new(((self.bits >> 20) & 0x01) != 0)
+        FRAC_EN_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bits 0:16 - Fraction In"]
     #[inline(always)]
