@@ -60,7 +60,7 @@ impl From<CLK_SRC_SEL_A> for u8 {
     }
 }
 #[doc = "Field `CLK_SRC_SEL` reader - Clock Source Select"]
-pub struct CLK_SRC_SEL_R(crate::FieldReader<u8, CLK_SRC_SEL_A>);
+pub struct CLK_SRC_SEL_R(crate::FieldReader<u8>);
 impl CLK_SRC_SEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -117,7 +117,7 @@ impl CLK_SRC_SEL_R {
     }
 }
 impl core::ops::Deref for CLK_SRC_SEL_R {
-    type Target = crate::FieldReader<u8, CLK_SRC_SEL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -171,12 +171,12 @@ impl<'a> CLK_SRC_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 24)) | ((value as u32 & 0x07) << 24);
+        self.w.bits = (self.w.bits & !(7 << 24)) | ((value as u32 & 7) << 24);
         self.w
     }
 }
 #[doc = "Field `AXI_DIV_CFG` reader - Factor N"]
-pub struct AXI_DIV_CFG_R(crate::FieldReader<u8, u8>);
+pub struct AXI_DIV_CFG_R(crate::FieldReader<u8>);
 impl AXI_DIV_CFG_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -184,7 +184,7 @@ impl AXI_DIV_CFG_R {
     }
 }
 impl core::ops::Deref for AXI_DIV_CFG_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -198,12 +198,12 @@ impl<'a> AXI_DIV_CFG_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
 #[doc = "Field `DIV_CFG` reader - Factor M"]
-pub struct DIV_CFG_R(crate::FieldReader<u8, u8>);
+pub struct DIV_CFG_R(crate::FieldReader<u8>);
 impl DIV_CFG_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -211,7 +211,7 @@ impl DIV_CFG_R {
     }
 }
 impl core::ops::Deref for DIV_CFG_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -233,12 +233,12 @@ impl R {
     #[doc = "Bits 24:26 - Clock Source Select"]
     #[inline(always)]
     pub fn clk_src_sel(&self) -> CLK_SRC_SEL_R {
-        CLK_SRC_SEL_R::new(((self.bits >> 24) & 0x07) as u8)
+        CLK_SRC_SEL_R::new(((self.bits >> 24) & 7) as u8)
     }
     #[doc = "Bits 8:9 - Factor N"]
     #[inline(always)]
     pub fn axi_div_cfg(&self) -> AXI_DIV_CFG_R {
-        AXI_DIV_CFG_R::new(((self.bits >> 8) & 0x03) as u8)
+        AXI_DIV_CFG_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 0:4 - Factor M"]
     #[inline(always)]
