@@ -49,7 +49,7 @@ impl From<SPI_RST_A> for bool {
     }
 }
 #[doc = "Fields `SPI(0-1)_RST` reader - Reset"]
-pub struct SPI_RST_R(crate::FieldReader<bool, SPI_RST_A>);
+pub struct SPI_RST_R(crate::FieldReader<bool>);
 impl SPI_RST_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,56 +75,17 @@ impl SPI_RST_R {
     }
 }
 impl core::ops::Deref for SPI_RST_R {
-    type Target = crate::FieldReader<bool, SPI_RST_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `SPI(0-1)_RST` writer - Reset"]
-pub struct SPI_RST_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> SPI_RST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SPI_RST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn assert(self) -> &'a mut W {
-        self.variant(SPI_RST_A::ASSERT)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn deassert(self) -> &'a mut W {
-        self.variant(SPI_RST_A::DEASSERT)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x01 << self.offset)) | ((value as u32 & 0x01) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `SPI(0-1)_RST` const generic writer - Reset"]
-pub struct SPI_RST_CGW<'a, const O: usize> {
+pub struct SPI_RST_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> SPI_RST_CGW<'a, O> {
+impl<'a, const O: usize> SPI_RST_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: SPI_RST_A) -> &'a mut W {
@@ -153,7 +114,7 @@ impl<'a, const O: usize> SPI_RST_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << O)) | ((value as u32 & 0x01) << O);
+        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
         self.w
     }
 }
@@ -172,7 +133,7 @@ impl From<SPI_GATING_A> for bool {
     }
 }
 #[doc = "Fields `SPI(0-1)_GATING` reader - Gating Clock"]
-pub struct SPI_GATING_R(crate::FieldReader<bool, SPI_GATING_A>);
+pub struct SPI_GATING_R(crate::FieldReader<bool>);
 impl SPI_GATING_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -198,56 +159,17 @@ impl SPI_GATING_R {
     }
 }
 impl core::ops::Deref for SPI_GATING_R {
-    type Target = crate::FieldReader<bool, SPI_GATING_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `SPI(0-1)_GATING` writer - Gating Clock"]
-pub struct SPI_GATING_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> SPI_GATING_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SPI_GATING_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn mask(self) -> &'a mut W {
-        self.variant(SPI_GATING_A::MASK)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn pass(self) -> &'a mut W {
-        self.variant(SPI_GATING_A::PASS)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x01 << self.offset)) | ((value as u32 & 0x01) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `SPI(0-1)_GATING` const generic writer - Gating Clock"]
-pub struct SPI_GATING_CGW<'a, const O: usize> {
+pub struct SPI_GATING_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> SPI_GATING_CGW<'a, O> {
+impl<'a, const O: usize> SPI_GATING_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: SPI_GATING_A) -> &'a mut W {
@@ -276,7 +198,7 @@ impl<'a, const O: usize> SPI_GATING_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << O)) | ((value as u32 & 0x01) << O);
+        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
         self.w
     }
 }
@@ -284,67 +206,64 @@ impl R {
     #[doc = "Reset"]
     #[inline(always)]
     pub unsafe fn spi_rst(&self, n: usize) -> SPI_RST_R {
-        SPI_RST_R::new(((self.bits >> (n + 16)) & 0x01) != 0)
+        SPI_RST_R::new(((self.bits >> (n + 16)) & 1) != 0)
     }
     #[doc = "Bit 16 - Reset"]
     #[inline(always)]
     pub fn spi0_rst(&self) -> SPI_RST_R {
-        SPI_RST_R::new(((self.bits >> 16) & 0x01) != 0)
+        SPI_RST_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - Reset"]
     #[inline(always)]
     pub fn spi1_rst(&self) -> SPI_RST_R {
-        SPI_RST_R::new(((self.bits >> 17) & 0x01) != 0)
+        SPI_RST_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Gating Clock"]
     #[inline(always)]
     pub unsafe fn spi_gating(&self, n: usize) -> SPI_GATING_R {
-        SPI_GATING_R::new(((self.bits >> n) & 0x01) != 0)
+        SPI_GATING_R::new(((self.bits >> n) & 1) != 0)
     }
     #[doc = "Bit 0 - Gating Clock"]
     #[inline(always)]
     pub fn spi0_gating(&self) -> SPI_GATING_R {
-        SPI_GATING_R::new((self.bits & 0x01) != 0)
+        SPI_GATING_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Gating Clock"]
     #[inline(always)]
     pub fn spi1_gating(&self) -> SPI_GATING_R {
-        SPI_GATING_R::new(((self.bits >> 1) & 0x01) != 0)
+        SPI_GATING_R::new(((self.bits >> 1) & 1) != 0)
     }
 }
 impl W {
     #[doc = "Reset"]
     #[inline(always)]
-    pub unsafe fn spi_rst(&mut self, n: usize) -> SPI_RST_W {
-        SPI_RST_W {
-            w: self,
-            offset: n + 16,
-        }
+    pub unsafe fn spi_rst<const O: usize>(&mut self) -> SPI_RST_W<O> {
+        SPI_RST_W { w: self }
     }
     #[doc = "Bit 16 - Reset"]
     #[inline(always)]
-    pub fn spi0_rst(&mut self) -> SPI_RST_CGW<16> {
-        SPI_RST_CGW { w: self }
+    pub fn spi0_rst(&mut self) -> SPI_RST_W<16> {
+        SPI_RST_W { w: self }
     }
     #[doc = "Bit 17 - Reset"]
     #[inline(always)]
-    pub fn spi1_rst(&mut self) -> SPI_RST_CGW<17> {
-        SPI_RST_CGW { w: self }
+    pub fn spi1_rst(&mut self) -> SPI_RST_W<17> {
+        SPI_RST_W { w: self }
     }
     #[doc = "Gating Clock"]
     #[inline(always)]
-    pub unsafe fn spi_gating(&mut self, n: usize) -> SPI_GATING_W {
-        SPI_GATING_W { w: self, offset: n }
+    pub unsafe fn spi_gating<const O: usize>(&mut self) -> SPI_GATING_W<O> {
+        SPI_GATING_W { w: self }
     }
     #[doc = "Bit 0 - Gating Clock"]
     #[inline(always)]
-    pub fn spi0_gating(&mut self) -> SPI_GATING_CGW<0> {
-        SPI_GATING_CGW { w: self }
+    pub fn spi0_gating(&mut self) -> SPI_GATING_W<0> {
+        SPI_GATING_W { w: self }
     }
     #[doc = "Bit 1 - Gating Clock"]
     #[inline(always)]
-    pub fn spi1_gating(&mut self) -> SPI_GATING_CGW<1> {
-        SPI_GATING_CGW { w: self }
+    pub fn spi1_gating(&mut self) -> SPI_GATING_W<1> {
+        SPI_GATING_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
