@@ -54,7 +54,7 @@ impl From<PD_DRV_A> for u8 {
     }
 }
 #[doc = "Fields `PD(16-22)_DRV` reader - PD Multi_Driving Select"]
-pub struct PD_DRV_R(crate::FieldReader<u8, PD_DRV_A>);
+pub struct PD_DRV_R(crate::FieldReader<u8>);
 impl PD_DRV_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -93,56 +93,17 @@ impl PD_DRV_R {
     }
 }
 impl core::ops::Deref for PD_DRV_R {
-    type Target = crate::FieldReader<u8, PD_DRV_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `PD(16-22)_DRV` writer - PD Multi_Driving Select"]
-pub struct PD_DRV_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> PD_DRV_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD_DRV_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn l0(self) -> &'a mut W {
-        self.variant(PD_DRV_A::L0)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn l1(self) -> &'a mut W {
-        self.variant(PD_DRV_A::L1)
-    }
-    #[doc = "`10`"]
-    #[inline(always)]
-    pub fn l2(self) -> &'a mut W {
-        self.variant(PD_DRV_A::L2)
-    }
-    #[doc = "`11`"]
-    #[inline(always)]
-    pub fn l3(self) -> &'a mut W {
-        self.variant(PD_DRV_A::L3)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x03 << self.offset)) | ((value as u32 & 0x03) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `PD(16-22)_DRV` const generic writer - PD Multi_Driving Select"]
-pub struct PD_DRV_CGW<'a, const O: usize> {
+pub struct PD_DRV_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> PD_DRV_CGW<'a, O> {
+impl<'a, const O: usize> PD_DRV_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: PD_DRV_A) -> &'a mut W {
@@ -171,7 +132,7 @@ impl<'a, const O: usize> PD_DRV_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << O)) | ((value as u32 & 0x03) << O);
+        self.w.bits = (self.w.bits & !(3 << O)) | ((value as u32 & 3) << O);
         self.w
     }
 }
@@ -179,87 +140,84 @@ impl R {
     #[doc = "PD Multi_Driving Select"]
     #[inline(always)]
     pub unsafe fn pd_drv(&self, n: usize) -> PD_DRV_R {
-        PD_DRV_R::new(((self.bits >> ((n - 16) * 4)) & 0x03) as u8)
+        PD_DRV_R::new(((self.bits >> ((n - 16) * 4)) & 3) as u8)
     }
     #[doc = "Bits 0:1 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd16_drv(&self) -> PD_DRV_R {
-        PD_DRV_R::new((self.bits & 0x03) as u8)
+        PD_DRV_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 4:5 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd17_drv(&self) -> PD_DRV_R {
-        PD_DRV_R::new(((self.bits >> 4) & 0x03) as u8)
+        PD_DRV_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 8:9 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd18_drv(&self) -> PD_DRV_R {
-        PD_DRV_R::new(((self.bits >> 8) & 0x03) as u8)
+        PD_DRV_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 12:13 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd19_drv(&self) -> PD_DRV_R {
-        PD_DRV_R::new(((self.bits >> 12) & 0x03) as u8)
+        PD_DRV_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 16:17 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd20_drv(&self) -> PD_DRV_R {
-        PD_DRV_R::new(((self.bits >> 16) & 0x03) as u8)
+        PD_DRV_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 20:21 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd21_drv(&self) -> PD_DRV_R {
-        PD_DRV_R::new(((self.bits >> 20) & 0x03) as u8)
+        PD_DRV_R::new(((self.bits >> 20) & 3) as u8)
     }
     #[doc = "Bits 24:25 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd22_drv(&self) -> PD_DRV_R {
-        PD_DRV_R::new(((self.bits >> 24) & 0x03) as u8)
+        PD_DRV_R::new(((self.bits >> 24) & 3) as u8)
     }
 }
 impl W {
     #[doc = "PD Multi_Driving Select"]
     #[inline(always)]
-    pub unsafe fn pd_drv(&mut self, n: usize) -> PD_DRV_W {
-        PD_DRV_W {
-            w: self,
-            offset: (n - 16) * 4,
-        }
+    pub unsafe fn pd_drv<const O: usize>(&mut self) -> PD_DRV_W<O> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Bits 0:1 - PD Multi_Driving Select"]
     #[inline(always)]
-    pub fn pd16_drv(&mut self) -> PD_DRV_CGW<0> {
-        PD_DRV_CGW { w: self }
+    pub fn pd16_drv(&mut self) -> PD_DRV_W<0> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Bits 4:5 - PD Multi_Driving Select"]
     #[inline(always)]
-    pub fn pd17_drv(&mut self) -> PD_DRV_CGW<4> {
-        PD_DRV_CGW { w: self }
+    pub fn pd17_drv(&mut self) -> PD_DRV_W<4> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Bits 8:9 - PD Multi_Driving Select"]
     #[inline(always)]
-    pub fn pd18_drv(&mut self) -> PD_DRV_CGW<8> {
-        PD_DRV_CGW { w: self }
+    pub fn pd18_drv(&mut self) -> PD_DRV_W<8> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Bits 12:13 - PD Multi_Driving Select"]
     #[inline(always)]
-    pub fn pd19_drv(&mut self) -> PD_DRV_CGW<12> {
-        PD_DRV_CGW { w: self }
+    pub fn pd19_drv(&mut self) -> PD_DRV_W<12> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Bits 16:17 - PD Multi_Driving Select"]
     #[inline(always)]
-    pub fn pd20_drv(&mut self) -> PD_DRV_CGW<16> {
-        PD_DRV_CGW { w: self }
+    pub fn pd20_drv(&mut self) -> PD_DRV_W<16> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Bits 20:21 - PD Multi_Driving Select"]
     #[inline(always)]
-    pub fn pd21_drv(&mut self) -> PD_DRV_CGW<20> {
-        PD_DRV_CGW { w: self }
+    pub fn pd21_drv(&mut self) -> PD_DRV_W<20> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Bits 24:25 - PD Multi_Driving Select"]
     #[inline(always)]
-    pub fn pd22_drv(&mut self) -> PD_DRV_CGW<24> {
-        PD_DRV_CGW { w: self }
+    pub fn pd22_drv(&mut self) -> PD_DRV_W<24> {
+        PD_DRV_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
