@@ -52,7 +52,7 @@ impl From<PE_PULL_A> for u8 {
     }
 }
 #[doc = "Fields `PE(0-15)_PULL` reader - PE Pull_up/down Select"]
-pub struct PE_PULL_R(crate::FieldReader<u8, PE_PULL_A>);
+pub struct PE_PULL_R(crate::FieldReader<u8>);
 impl PE_PULL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -85,51 +85,17 @@ impl PE_PULL_R {
     }
 }
 impl core::ops::Deref for PE_PULL_R {
-    type Target = crate::FieldReader<u8, PE_PULL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `PE(0-15)_PULL` writer - PE Pull_up/down Select"]
-pub struct PE_PULL_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> PE_PULL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PE_PULL_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn pull_disable(self) -> &'a mut W {
-        self.variant(PE_PULL_A::PULL_DISABLE)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn pull_up(self) -> &'a mut W {
-        self.variant(PE_PULL_A::PULL_UP)
-    }
-    #[doc = "`10`"]
-    #[inline(always)]
-    pub fn pull_down(self) -> &'a mut W {
-        self.variant(PE_PULL_A::PULL_DOWN)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x03 << self.offset)) | ((value as u32 & 0x03) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `PE(0-15)_PULL` const generic writer - PE Pull_up/down Select"]
-pub struct PE_PULL_CGW<'a, const O: usize> {
+pub struct PE_PULL_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> PE_PULL_CGW<'a, O> {
+impl<'a, const O: usize> PE_PULL_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: PE_PULL_A) -> &'a mut W {
@@ -153,7 +119,7 @@ impl<'a, const O: usize> PE_PULL_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << O)) | ((value as u32 & 0x03) << O);
+        self.w.bits = (self.w.bits & !(3 << O)) | ((value as u32 & 3) << O);
         self.w
     }
 }
@@ -161,177 +127,174 @@ impl R {
     #[doc = "PE Pull_up/down Select"]
     #[inline(always)]
     pub unsafe fn pe_pull(&self, n: usize) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> (n * 2)) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> (n * 2)) & 3) as u8)
     }
     #[doc = "Bits 0:1 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe0_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new((self.bits & 0x03) as u8)
+        PE_PULL_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 2:3 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe1_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 2) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bits 4:5 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe2_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 4) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 6:7 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe3_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 6) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bits 8:9 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe4_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 8) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 10:11 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe5_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 10) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bits 12:13 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe6_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 12) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 14:15 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe7_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 14) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 14) & 3) as u8)
     }
     #[doc = "Bits 16:17 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe8_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 16) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 18:19 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe9_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 18) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 18) & 3) as u8)
     }
     #[doc = "Bits 20:21 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe10_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 20) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 20) & 3) as u8)
     }
     #[doc = "Bits 22:23 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe11_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 22) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 22) & 3) as u8)
     }
     #[doc = "Bits 24:25 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe12_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 24) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bits 26:27 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe13_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 26) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 26) & 3) as u8)
     }
     #[doc = "Bits 28:29 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe14_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 28) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 28) & 3) as u8)
     }
     #[doc = "Bits 30:31 - PE Pull_up/down Select"]
     #[inline(always)]
     pub fn pe15_pull(&self) -> PE_PULL_R {
-        PE_PULL_R::new(((self.bits >> 30) & 0x03) as u8)
+        PE_PULL_R::new(((self.bits >> 30) & 3) as u8)
     }
 }
 impl W {
     #[doc = "PE Pull_up/down Select"]
     #[inline(always)]
-    pub unsafe fn pe_pull(&mut self, n: usize) -> PE_PULL_W {
-        PE_PULL_W {
-            w: self,
-            offset: n * 2,
-        }
+    pub unsafe fn pe_pull<const O: usize>(&mut self) -> PE_PULL_W<O> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 0:1 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe0_pull(&mut self) -> PE_PULL_CGW<0> {
-        PE_PULL_CGW { w: self }
+    pub fn pe0_pull(&mut self) -> PE_PULL_W<0> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 2:3 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe1_pull(&mut self) -> PE_PULL_CGW<2> {
-        PE_PULL_CGW { w: self }
+    pub fn pe1_pull(&mut self) -> PE_PULL_W<2> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 4:5 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe2_pull(&mut self) -> PE_PULL_CGW<4> {
-        PE_PULL_CGW { w: self }
+    pub fn pe2_pull(&mut self) -> PE_PULL_W<4> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 6:7 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe3_pull(&mut self) -> PE_PULL_CGW<6> {
-        PE_PULL_CGW { w: self }
+    pub fn pe3_pull(&mut self) -> PE_PULL_W<6> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 8:9 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe4_pull(&mut self) -> PE_PULL_CGW<8> {
-        PE_PULL_CGW { w: self }
+    pub fn pe4_pull(&mut self) -> PE_PULL_W<8> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 10:11 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe5_pull(&mut self) -> PE_PULL_CGW<10> {
-        PE_PULL_CGW { w: self }
+    pub fn pe5_pull(&mut self) -> PE_PULL_W<10> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 12:13 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe6_pull(&mut self) -> PE_PULL_CGW<12> {
-        PE_PULL_CGW { w: self }
+    pub fn pe6_pull(&mut self) -> PE_PULL_W<12> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 14:15 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe7_pull(&mut self) -> PE_PULL_CGW<14> {
-        PE_PULL_CGW { w: self }
+    pub fn pe7_pull(&mut self) -> PE_PULL_W<14> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 16:17 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe8_pull(&mut self) -> PE_PULL_CGW<16> {
-        PE_PULL_CGW { w: self }
+    pub fn pe8_pull(&mut self) -> PE_PULL_W<16> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 18:19 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe9_pull(&mut self) -> PE_PULL_CGW<18> {
-        PE_PULL_CGW { w: self }
+    pub fn pe9_pull(&mut self) -> PE_PULL_W<18> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 20:21 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe10_pull(&mut self) -> PE_PULL_CGW<20> {
-        PE_PULL_CGW { w: self }
+    pub fn pe10_pull(&mut self) -> PE_PULL_W<20> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 22:23 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe11_pull(&mut self) -> PE_PULL_CGW<22> {
-        PE_PULL_CGW { w: self }
+    pub fn pe11_pull(&mut self) -> PE_PULL_W<22> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 24:25 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe12_pull(&mut self) -> PE_PULL_CGW<24> {
-        PE_PULL_CGW { w: self }
+    pub fn pe12_pull(&mut self) -> PE_PULL_W<24> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 26:27 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe13_pull(&mut self) -> PE_PULL_CGW<26> {
-        PE_PULL_CGW { w: self }
+    pub fn pe13_pull(&mut self) -> PE_PULL_W<26> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 28:29 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe14_pull(&mut self) -> PE_PULL_CGW<28> {
-        PE_PULL_CGW { w: self }
+    pub fn pe14_pull(&mut self) -> PE_PULL_W<28> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Bits 30:31 - PE Pull_up/down Select"]
     #[inline(always)]
-    pub fn pe15_pull(&mut self) -> PE_PULL_CGW<30> {
-        PE_PULL_CGW { w: self }
+    pub fn pe15_pull(&mut self) -> PE_PULL_W<30> {
+        PE_PULL_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
