@@ -35,7 +35,7 @@ impl From<crate::W<DBI_INT_SPEC>> for W {
     }
 }
 #[doc = "Field `dbi_fifo_empty_int` reader - "]
-pub struct DBI_FIFO_EMPTY_INT_R(crate::FieldReader<bool, bool>);
+pub struct DBI_FIFO_EMPTY_INT_R(crate::FieldReader<bool>);
 impl DBI_FIFO_EMPTY_INT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl DBI_FIFO_EMPTY_INT_R {
     }
 }
 impl core::ops::Deref for DBI_FIFO_EMPTY_INT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> DBI_FIFO_EMPTY_INT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `dbi_fifo_full_int` reader - "]
-pub struct DBI_FIFO_FULL_INT_R(crate::FieldReader<bool, bool>);
+pub struct DBI_FIFO_FULL_INT_R(crate::FieldReader<bool>);
 impl DBI_FIFO_FULL_INT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,7 +80,7 @@ impl DBI_FIFO_FULL_INT_R {
     }
 }
 impl core::ops::Deref for DBI_FIFO_FULL_INT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -104,12 +104,12 @@ impl<'a> DBI_FIFO_FULL_INT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `timer_int` reader - "]
-pub struct TIMER_INT_R(crate::FieldReader<bool, bool>);
+pub struct TIMER_INT_R(crate::FieldReader<bool>);
 impl TIMER_INT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -117,7 +117,7 @@ impl TIMER_INT_R {
     }
 }
 impl core::ops::Deref for TIMER_INT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,12 +141,12 @@ impl<'a> TIMER_INT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `rd_done_int` reader - "]
-pub struct RD_DONE_INT_R(crate::FieldReader<bool, bool>);
+pub struct RD_DONE_INT_R(crate::FieldReader<bool>);
 impl RD_DONE_INT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -154,7 +154,7 @@ impl RD_DONE_INT_R {
     }
 }
 impl core::ops::Deref for RD_DONE_INT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -178,12 +178,12 @@ impl<'a> RD_DONE_INT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `te_int` reader - "]
-pub struct TE_INT_R(crate::FieldReader<bool, bool>);
+pub struct TE_INT_R(crate::FieldReader<bool>);
 impl TE_INT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -191,7 +191,7 @@ impl TE_INT_R {
     }
 }
 impl core::ops::Deref for TE_INT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -215,12 +215,12 @@ impl<'a> TE_INT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `fram_done_int` reader - "]
-pub struct FRAM_DONE_INT_R(crate::FieldReader<bool, bool>);
+pub struct FRAM_DONE_INT_R(crate::FieldReader<bool>);
 impl FRAM_DONE_INT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -228,7 +228,7 @@ impl FRAM_DONE_INT_R {
     }
 }
 impl core::ops::Deref for FRAM_DONE_INT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -252,12 +252,12 @@ impl<'a> FRAM_DONE_INT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `line_done_int` reader - "]
-pub struct LINE_DONE_INT_R(crate::FieldReader<bool, bool>);
+pub struct LINE_DONE_INT_R(crate::FieldReader<bool>);
 impl LINE_DONE_INT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -265,7 +265,7 @@ impl LINE_DONE_INT_R {
     }
 }
 impl core::ops::Deref for LINE_DONE_INT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -289,12 +289,12 @@ impl<'a> LINE_DONE_INT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `dbi_fifo_empty_int_en` reader - "]
-pub struct DBI_FIFO_EMPTY_INT_EN_R(crate::FieldReader<bool, bool>);
+pub struct DBI_FIFO_EMPTY_INT_EN_R(crate::FieldReader<bool>);
 impl DBI_FIFO_EMPTY_INT_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -302,7 +302,7 @@ impl DBI_FIFO_EMPTY_INT_EN_R {
     }
 }
 impl core::ops::Deref for DBI_FIFO_EMPTY_INT_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -326,12 +326,12 @@ impl<'a> DBI_FIFO_EMPTY_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `dbi_fifo_full_int_en` reader - "]
-pub struct DBI_FIFO_FULL_INT_EN_R(crate::FieldReader<bool, bool>);
+pub struct DBI_FIFO_FULL_INT_EN_R(crate::FieldReader<bool>);
 impl DBI_FIFO_FULL_INT_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -339,7 +339,7 @@ impl DBI_FIFO_FULL_INT_EN_R {
     }
 }
 impl core::ops::Deref for DBI_FIFO_FULL_INT_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -363,12 +363,12 @@ impl<'a> DBI_FIFO_FULL_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `timer_int_en` reader - "]
-pub struct TIMER_INT_EN_R(crate::FieldReader<bool, bool>);
+pub struct TIMER_INT_EN_R(crate::FieldReader<bool>);
 impl TIMER_INT_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -376,7 +376,7 @@ impl TIMER_INT_EN_R {
     }
 }
 impl core::ops::Deref for TIMER_INT_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -400,12 +400,12 @@ impl<'a> TIMER_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `rd_done_int_en` reader - "]
-pub struct RD_DONE_INT_EN_R(crate::FieldReader<bool, bool>);
+pub struct RD_DONE_INT_EN_R(crate::FieldReader<bool>);
 impl RD_DONE_INT_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -413,7 +413,7 @@ impl RD_DONE_INT_EN_R {
     }
 }
 impl core::ops::Deref for RD_DONE_INT_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,12 +437,12 @@ impl<'a> RD_DONE_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `te_int_en` reader - "]
-pub struct TE_INT_EN_R(crate::FieldReader<bool, bool>);
+pub struct TE_INT_EN_R(crate::FieldReader<bool>);
 impl TE_INT_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -450,7 +450,7 @@ impl TE_INT_EN_R {
     }
 }
 impl core::ops::Deref for TE_INT_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -474,12 +474,12 @@ impl<'a> TE_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `fram_done_int_en` reader - "]
-pub struct FRAM_DONE_INT_EN_R(crate::FieldReader<bool, bool>);
+pub struct FRAM_DONE_INT_EN_R(crate::FieldReader<bool>);
 impl FRAM_DONE_INT_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -487,7 +487,7 @@ impl FRAM_DONE_INT_EN_R {
     }
 }
 impl core::ops::Deref for FRAM_DONE_INT_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -511,12 +511,12 @@ impl<'a> FRAM_DONE_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `line_done_int_en` reader - "]
-pub struct LINE_DONE_INT_EN_R(crate::FieldReader<bool, bool>);
+pub struct LINE_DONE_INT_EN_R(crate::FieldReader<bool>);
 impl LINE_DONE_INT_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -524,7 +524,7 @@ impl LINE_DONE_INT_EN_R {
     }
 }
 impl core::ops::Deref for LINE_DONE_INT_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -548,7 +548,7 @@ impl<'a> LINE_DONE_INT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -556,72 +556,72 @@ impl R {
     #[doc = "Bit 14"]
     #[inline(always)]
     pub fn dbi_fifo_empty_int(&self) -> DBI_FIFO_EMPTY_INT_R {
-        DBI_FIFO_EMPTY_INT_R::new(((self.bits >> 14) & 0x01) != 0)
+        DBI_FIFO_EMPTY_INT_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 13"]
     #[inline(always)]
     pub fn dbi_fifo_full_int(&self) -> DBI_FIFO_FULL_INT_R {
-        DBI_FIFO_FULL_INT_R::new(((self.bits >> 13) & 0x01) != 0)
+        DBI_FIFO_FULL_INT_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 12"]
     #[inline(always)]
     pub fn timer_int(&self) -> TIMER_INT_R {
-        TIMER_INT_R::new(((self.bits >> 12) & 0x01) != 0)
+        TIMER_INT_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 11"]
     #[inline(always)]
     pub fn rd_done_int(&self) -> RD_DONE_INT_R {
-        RD_DONE_INT_R::new(((self.bits >> 11) & 0x01) != 0)
+        RD_DONE_INT_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 10"]
     #[inline(always)]
     pub fn te_int(&self) -> TE_INT_R {
-        TE_INT_R::new(((self.bits >> 10) & 0x01) != 0)
+        TE_INT_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 9"]
     #[inline(always)]
     pub fn fram_done_int(&self) -> FRAM_DONE_INT_R {
-        FRAM_DONE_INT_R::new(((self.bits >> 9) & 0x01) != 0)
+        FRAM_DONE_INT_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 8"]
     #[inline(always)]
     pub fn line_done_int(&self) -> LINE_DONE_INT_R {
-        LINE_DONE_INT_R::new(((self.bits >> 8) & 0x01) != 0)
+        LINE_DONE_INT_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 6"]
     #[inline(always)]
     pub fn dbi_fifo_empty_int_en(&self) -> DBI_FIFO_EMPTY_INT_EN_R {
-        DBI_FIFO_EMPTY_INT_EN_R::new(((self.bits >> 6) & 0x01) != 0)
+        DBI_FIFO_EMPTY_INT_EN_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 5"]
     #[inline(always)]
     pub fn dbi_fifo_full_int_en(&self) -> DBI_FIFO_FULL_INT_EN_R {
-        DBI_FIFO_FULL_INT_EN_R::new(((self.bits >> 5) & 0x01) != 0)
+        DBI_FIFO_FULL_INT_EN_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 4"]
     #[inline(always)]
     pub fn timer_int_en(&self) -> TIMER_INT_EN_R {
-        TIMER_INT_EN_R::new(((self.bits >> 4) & 0x01) != 0)
+        TIMER_INT_EN_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 3"]
     #[inline(always)]
     pub fn rd_done_int_en(&self) -> RD_DONE_INT_EN_R {
-        RD_DONE_INT_EN_R::new(((self.bits >> 3) & 0x01) != 0)
+        RD_DONE_INT_EN_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 2"]
     #[inline(always)]
     pub fn te_int_en(&self) -> TE_INT_EN_R {
-        TE_INT_EN_R::new(((self.bits >> 2) & 0x01) != 0)
+        TE_INT_EN_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1"]
     #[inline(always)]
     pub fn fram_done_int_en(&self) -> FRAM_DONE_INT_EN_R {
-        FRAM_DONE_INT_EN_R::new(((self.bits >> 1) & 0x01) != 0)
+        FRAM_DONE_INT_EN_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0"]
     #[inline(always)]
     pub fn line_done_int_en(&self) -> LINE_DONE_INT_EN_R {
-        LINE_DONE_INT_EN_R::new((self.bits & 0x01) != 0)
+        LINE_DONE_INT_EN_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
